@@ -42,14 +42,16 @@
 
 /*** DOCUMENTATION
 	<application name="Gosub" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Jump to label, saving return address.
 		</synopsis>
 		<syntax>
-			<parameter name="context" />
-			<parameter name="exten" />
-			<parameter name="priority" required="true" hasparams="optional">
+			<parameter name="context" documentationtype="dialplan_context" />
+			<parameter name="extension" documentationtype="dialplan_extension" />
+			<parameter name="priority" documentationtype="dialplan_priority" required="true" hasparams="optional">
 				<argument name="arg1" multiple="true" required="true" />
 				<argument name="argN" />
 			</parameter>
@@ -65,7 +67,9 @@
 		</see-also>
 	</application>
 	<application name="GosubIf" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Conditionally jump to label, saving return address.
 		</synopsis>
@@ -100,7 +104,9 @@
 		</see-also>
 	</application>
 	<application name="Return" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Return from gosub routine.
 		</synopsis>
@@ -119,7 +125,9 @@
 		</see-also>
 	</application>
 	<application name="StackPop" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Remove one address from gosub stack.
 		</synopsis>
@@ -133,7 +141,9 @@
 		</see-also>
 	</application>
 	<function name="LOCAL" language="en_US">
-		<since><version>1.6.1.0</version></since>
+		<since>
+			<version>1.6.1.0</version>
+		</since>
 		<synopsis>
 			Manage variables local to the gosub stack frame.
 		</synopsis>
@@ -151,7 +161,9 @@
 		</see-also>
 	</function>
 	<function name="LOCAL_PEEK" language="en_US">
-		<since><version>1.6.1.0</version></since>
+		<since>
+			<version>1.6.1.0</version>
+		</since>
 		<synopsis>
 			Retrieve variables hidden by the local gosub stack frame.
 		</synopsis>
@@ -174,7 +186,10 @@
 		</see-also>
 	</function>
 	<function name="STACK_PEEK" language="en_US">
-		<since><version>1.8.11.0</version><version>10.3.0</version></since>
+		<since>
+			<version>1.8.11.0</version>
+			<version>10.3.0</version>
+		</since>
 		<synopsis>
 			View info about the location which called Gosub
 		</synopsis>
@@ -212,7 +227,9 @@
 	</agi>
 	<managerEvent language="en_US" name="VarSet">
 		<managerEventInstance class="EVENT_FLAG_DIALPLAN">
-			<since><version>12.0.0</version></since>
+			<since>
+				<version>12.0.0</version>
+			</since>
 			<synopsis>Raised when a variable local to the gosub stack frame is set due to a subroutine call.</synopsis>
 			<syntax>
 				<channel_snapshot/>
