@@ -35,7 +35,9 @@
 
 /*** DOCUMENTATION
 	<function name="GROUP_COUNT" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Counts the number of channels in the specified group.
 		</synopsis>
@@ -53,7 +55,9 @@
 		</description>
 	</function>
 	<function name="GROUP_MATCH_COUNT" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Counts the number of channels in the groups matching the specified pattern.
 		</synopsis>
@@ -72,7 +76,9 @@
 		</description>
 	</function>
 	<function name="GROUP" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Gets or sets the channel group.
 		</synopsis>
@@ -87,7 +93,9 @@
 		</description>
 	</function>
 	<function name="GROUP_LIST" language="en_US">
-		<since><version>1.6.2.0</version></since>
+		<since>
+			<version>1.2.0</version>
+		</since>
 		<synopsis>
 			Gets a list of the groups set on a channel.
 		</synopsis>
